Documentation
¶
Rendered for js/wasm
Index ¶
- func ApplyExampleHydratedRouter(parseRouter *router.Router)
- func ApplyExampleHydration(parseRoot ui.Node, parseOptions ...ui.HydrationOptions) (ui.SSRBootstrap, error)
- func GetExampleMountSelector() string
- func HasExampleMountSelector() bool
- func RenderExampleRoot(parseRoot ui.Node)
- func RenderExampleRouter(parseRouter *router.Router)
- func WaitExampleRuntime()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyExampleHydratedRouter ¶
ApplyExampleHydratedRouter binds a hydrated router to the current example host selector.
func ApplyExampleHydration ¶
func ApplyExampleHydration(parseRoot ui.Node, parseOptions ...ui.HydrationOptions) (ui.SSRBootstrap, error)
ApplyExampleHydration hydrates the example root into the current example host selector.
func GetExampleMountSelector ¶
func GetExampleMountSelector() string
GetExampleMountSelector returns the host-provided selector used to mount an example.
func HasExampleMountSelector ¶
func HasExampleMountSelector() bool
HasExampleMountSelector reports whether the host provided an explicit example mount selector.
func RenderExampleRoot ¶
RenderExampleRoot mounts the example root into the current example host selector.
func RenderExampleRouter ¶
RenderExampleRouter mounts the router into the current example host selector.
func WaitExampleRuntime ¶
func WaitExampleRuntime()
WaitExampleRuntime keeps the example process alive after mounting.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.